@@ -25,6 +25,8 @@ extensions = [
     # 'sphinx.ext.intersphinx',
     'openstackdocstheme',
     'oslo_config.sphinxext',
+    'oslo_policy.sphinxext',
+    'oslo_policy.sphinxpolicygen',
 ]
 
 # autodoc generation is a bit aggressive and a nuisance when doing heavy
@@ -65,19 +67,22 @@ html_theme = 'openstackdocs'
 repository_name = 'openstack/%s' % project
 bug_project = project
 bug_tag = 'doc'
-html_last_updated_fmt = '%Y-%m-%d %H:%M'
 
 # Output file base name for HTML help builder.
 htmlhelp_basename = '%sdoc' % project
 
 # Grouping the document tree into LaTeX files. List of tuples
 # (source start file, target name, title, author, documentclass
-# [howto/manual]).
+# [howto/manual], torctree_only).
 latex_documents = [
     ('index',
-     '%s.tex' % project,
-     u'%s Documentation' % project,
-     u'OpenStack Foundation', 'manual'),
+     'doc-%s.tex' % project,
+     u'Networking Midonet Documentation',
+     u'OpenStack Foundation',
+     'manual',
+     # Specify toctree_only=True for a better document structure of
+     # the generated PDF file.
+     True),
 ]
 
 # Example configuration for intersphinx: refer to the Python standard library.
@@ -94,3 +99,8 @@ autodoc_mock_imports = [
     # "no IPRoute module for the platform" on OS X
     'neutron.agent.linux.ip_lib',
 ]
+
+# -- Options for oslo_policy.sphinxpolicygen ---------------------------------
+
+policy_generator_config_file = '../../etc/oslo-policy-generator/policy.conf'
+sample_policy_basename = '_static/networking-midonet'
