@@ -75,7 +75,7 @@ class MidonetL3DBMixin(l3_gwmode_db.L3_NAT_db_mixin):
             l3_models.RouterPort.router_id,
             models_v2.IPAllocation.ip_address
         ).join(
-            models_v2.Port, models_v2.IPAllocation
+            l3_models.RouterPort.port, models_v2.Port.fixed_ips
         ).filter(
             models_v2.Port.network_id == internal_port['network_id'],
             l3_models.RouterPort.port_type.in_(
@@ -226,7 +226,7 @@ class MidonetL3DBMixin(l3_gwmode_db.L3_NAT_db_mixin):
             # Update association with internal port
             # and define external IP address
             assoc_result = self._update_fip_assoc(
-                context, fip, floatingip_obj, external_port)
+                context, fip, floatingip_obj)
             floatingip_obj.create()
             floatingip_dict = self._make_floatingip_dict(
                 floatingip_obj, process_extensions=False)
