@@ -13,7 +13,13 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from neutron.common import constants
+from neutron_lib.api.definitions import portbindings
+from neutron_lib import constants as n_const
+from neutron_lib import exceptions as n_exc
+from neutron_lib.plugins.ml2 import api
+from oslo_config import cfg
+from oslo_log import helpers as log_helpers
+from oslo_log import log as logging
 
 from midonet.neutron._i18n import _
 from midonet.neutron.client import base as c_base
@@ -22,14 +28,7 @@ from midonet.neutron.common import constants as const
 from midonet.neutron.common import utils as c_utils
 from midonet.neutron.ml2 import sg_callback
 from midonet.neutron.ml2 import util as m_util
-
-from neutron.common import constants as n_const
-from neutron.common import exceptions as n_exc
-from neutron.extensions import portbindings
-from neutron.plugins.ml2 import driver_api as api
-from oslo_config import cfg
-from oslo_log import helpers as log_helpers
-from oslo_log import log as logging
+from midonet.neutron.services.qos import driver as qos_driver
 
 LOG = logging.getLogger(__name__)
 
@@ -41,11 +40,15 @@ class MidonetMechanismDriver(api.MechanismDriver):
     def __init__(self):
         self.vif_type = const.VIF_TYPE_MIDONET
         self.supported_vnic_types = [portbindings.VNIC_NORMAL]
-        self.vif_details = {portbindings.CAP_PORT_FILTER: True}
+        self.vif_details = {portbindings.CAP_PORT_FILTER: True,
+                            portbindings.VIF_DETAILS_CONNECTIVITY:
+                                portbindings.CONNECTIVITY_L2}
 
         self.client = c_base.load_client(cfg.CONF.MIDONET)
         self.client.initialize()
 
+        qos_driver.register()
+
     def initialize(self):
         self.sec_handler = sg_callback.MidonetSecurityGroupsHandler(
             self.client)
@@ -78,8 +81,6 @@ class MidonetMechanismDriver(api.MechanismDriver):
     @log_helpers.log_method_call
     def delete_network_precommit(self, context):
         network_id = context.current['id']
-        c_utils.check_delete_network_precommit(context._plugin_context,
-                                               network_id)
         self.client.delete_network_precommit(context, network_id)
 
     @m_util.filter_midonet_network
@@ -176,7 +177,7 @@ class MidonetMechanismDriver(api.MechanismDriver):
                 context.set_binding(segment[api.ID],
                                     self.vif_type,
                                     self.vif_details,
-                                    constants.PORT_STATUS_ACTIVE)
+                                    n_const.PORT_STATUS_ACTIVE)
                 break
             else:
                 LOG.debug(('midonet mechanism driver did NOT bind '
